.. _recipe_asr.setup.scanparams:

asr.setup.scanparams
====================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setup.scanparams`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.setup.scanparams.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setup.scanparams

or as a python module

.. code-block:: console

   $ python -m asr.setup.scanparams

Detailed description
--------------------
Generate folder with different parameters.

Steps
-----


asr.setup.scanparams
^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.scanparams.main
   